Module entity_resolver

Module entity_resolver 

Entity resolution for federation _entities query.

Structs

EntityResolutionMetrics
Result of batch entity resolution with timing information
EntityResolutionResult
Result of entity resolution

Functions

batch_load_entities
Batch load entities from database
batch_load_entities_with_tracing
Batch load entities from database with optional distributed tracing and metrics.
batch_load_entities_with_tracing_and_metrics
Batch load entities with full metrics for observability.
construct_batch_where_clause
Construct WHERE clause for batch query
deduplicate_representations
Deduplicate entity representations while preserving order
group_entities_by_typename
Group entities by typename and strategy
resolve_entities_from_db
Resolve entities for a specific typename from local database
resolve_entities_from_db_with_tracing
Resolve entities for a specific typename from local database with optional distributed tracing.