KafkaAdapter

Struct KafkaAdapter 

pub struct KafkaAdapter { /* private fields */ }
Kafka transport adapter stub (without kafka feature).

This is a stub implementation for development and testing. Enable the kafka feature for actual Kafka delivery.

Implementations

Source

impl KafkaAdapter

pub fn new(config: KafkaConfig) -> Result<Self, SubscriptionError>

Create a new Kafka adapter stub.

Note

This is a stub implementation. Enable the kafka feature for actual delivery.

Errors

This stub implementation never fails, but returns Result for API compatibility.