DirectiveLocationKind

Enum DirectiveLocationKind 

pub enum DirectiveLocationKind {
Show 19 variants Query, Mutation, Subscription, Field, FragmentDefinition, FragmentSpread, InlineFragment, VariableDefinition, Schema, Scalar, Object, FieldDefinition, ArgumentDefinition, Interface, Union, Enum, EnumValue, InputObject, InputFieldDefinition,
}
Directive location kinds for custom directive definitions.

This mirrors DirectiveLocation in introspection but is used for compiled schema definitions. The two types can be converted between each other for introspection purposes.

Per GraphQL spec 3.13, directive locations fall into two categories:

  • Executable locations (operations, fields, fragments)
  • Type system locations (schema definitions)

Variants



Query

Directive on query operation.



Mutation

Directive on mutation operation.



Subscription

Directive on subscription operation.



Field

Directive on field selection.



FragmentDefinition

Directive on fragment definition.



FragmentSpread

Directive on fragment spread.



InlineFragment

Directive on inline fragment.



VariableDefinition

Directive on variable definition.



Schema

Directive on schema definition.



Scalar

Directive on scalar type definition.



Object

Directive on object type definition.



FieldDefinition

Directive on field definition.



ArgumentDefinition

Directive on argument definition.



Interface

Directive on interface definition.



Union

Directive on union definition.



Enum

Directive on enum definition.



EnumValue

Directive on enum value definition.



InputObject

Directive on input object definition.



InputFieldDefinition

Directive on input field definition.

Implementations

Source

impl DirectiveLocationKind

pub fn is_executable(&self) -> bool

Check if this is an executable directive location.

pub fn is_type_system(&self) -> bool

Check if this is a type system directive location.