ArgumentDefinition

Struct ArgumentDefinition 

pub struct ArgumentDefinition {
    pub name: String,
    pub arg_type: FieldType,
    pub nullable: bool,
    pub default_value: Option<Value>,
    pub description: Option<String>,
    pub deprecation: Option<DeprecationInfo>,
}
Query/mutation/subscription argument definition.

Fields

name: String

Argument name.

arg_type: FieldType

Argument type.

nullable: bool

Is this argument optional?

default_value: Option<Value>

Default value (JSON representation).

description: Option<String>

Description.

deprecation: Option<DeprecationInfo>

Deprecation information (from @deprecated directive). When set, this argument is marked as deprecated in the schema. Per GraphQL spec, deprecated arguments should still be accepted but clients are encouraged to migrate to alternatives.

Implementations

Source

impl ArgumentDefinition

pub fn new(name: impl Into<String>, arg_type: FieldType) -> Self

Create a new required argument.

pub fn optional(name: impl Into<String>, arg_type: FieldType) -> Self

Create a new optional argument.

pub fn deprecated(self, reason: Option<String>) -> Self

Mark this argument as deprecated.

Example
use fraiseql_core::schema::{ArgumentDefinition, FieldType};

let arg = ArgumentDefinition::optional("oldLimit", FieldType::Int)
    .deprecated(Some("Use 'first' instead".to_string()));
assert!(arg.is_deprecated());
pub fn is_deprecated(&self) -> bool

Check if this argument is deprecated.

pub fn deprecation_reason(&self) -> Option<&str>

Get the deprecation reason if deprecated.