pub struct DeprecationInfo {
pub reason: Option<String>,
}Expand description
Deprecation information for a field or type.
Per GraphQL spec 4.4, deprecated fields should include a reason explaining why the field is deprecated and what to use instead.
Example
use fraiseql_core::schema::DeprecationInfo;
let deprecation = DeprecationInfo {
reason: Some("Use 'userId' instead".to_string()),
};Fields
reason: Option<String>Deprecation reason (what to use instead).