pub struct EnumDefinition {
pub name: String,
pub values: Vec<EnumValueDefinition>,
pub description: Option<String>,
}Expand description
A GraphQL enum type definition.
Enums represent a finite set of possible values, useful for categorization fields like status, role, or priority.
Example
use fraiseql_core::schema::{EnumDefinition, EnumValueDefinition};
let status_enum = EnumDefinition {
name: "OrderStatus".to_string(),
values: vec![
EnumValueDefinition::new("PENDING"),
EnumValueDefinition::new("PROCESSING"),
EnumValueDefinition::new("SHIPPED"),
EnumValueDefinition::new("DELIVERED"),
],
description: Some("Possible states of an order".to_string()),
};Fields
name: StringEnum type name (e.g., “OrderStatus”).
values: Vec<EnumValueDefinition>Possible values for this enum.
description: Option<String>Description of the enum type.
Implementations
Sourceimpl EnumDefinition
impl EnumDefinition
Sourcepub fn with_value(self, value: EnumValueDefinition) -> Self
pub fn with_value(self, value: EnumValueDefinition) -> Self
Add a value to this enum.
Sourcepub fn with_values(self, values: Vec<EnumValueDefinition>) -> Self
pub fn with_values(self, values: Vec<EnumValueDefinition>) -> Self
Add multiple values to this enum.
Sourcepub fn with_description(self, description: impl Into<String>) -> Self
pub fn with_description(self, description: impl Into<String>) -> Self
Set description.
Sourcepub fn find_value(&self, name: &str) -> Option<&EnumValueDefinition>
pub fn find_value(&self, name: &str) -> Option<&EnumValueDefinition>
Find a value by name.