#[non_exhaustive]pub enum FailurePolicy {
FailOpen,
FailClosed,
}Expand description
Policy controlling what happens when the replay-cache backend is unavailable.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FailOpen
Accept the token and log a warning. Prevents auth outages during backend downtime at the cost of reduced replay protection during the outage.
FailClosed
Reject the token. Maximum security, but any backend hiccup causes auth failures.