Module elo_rust_integration

Module elo_rust_integration 

Elo Rust target integration for compiled validators.

Provides infrastructure for compiling Elo expressions to Rust validators, caching compiled validators, and executing them with <1µs latency targets.

Elo is an expression language by Bernard Lambeau: https://elo-lang.org/

Structs

EloRustValidator
A single ELO Rust validator with generated code
RustValidatorRegistry
Registry for managing ELO Rust validators
RustValidatorRegistryConfig
Configuration for the Rust validator registry