#[non_exhaustive]pub enum InputObjectRule {
AnyOf {
fields: Vec<String>,
},
OneOf {
fields: Vec<String>,
},
ConditionalRequired {
if_field: String,
then_fields: Vec<String>,
},
RequiredIfAbsent {
absent_field: String,
then_fields: Vec<String>,
},
Custom {
name: String,
},
}Expand description
Rules that apply at the input object level.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AnyOf
At least one field from the set must be provided
OneOf
Exactly one field from the set must be provided
ConditionalRequired
If one field is present, others must be present
Fields
RequiredIfAbsent
If one field is absent, others must be present
Fields
Custom
Custom validator function name to invoke