pub struct LengthValidator { /* private fields */ }Expand description
String length validator.
Implementations
Sourceimpl LengthValidator
impl LengthValidator
Sourcepub fn validate_length(&self, value: &str) -> bool
pub fn validate_length(&self, value: &str) -> bool
Validate that a string is within the specified length bounds.
Sourcepub fn error_message(&self) -> String
pub fn error_message(&self) -> String
Get a descriptive error message for length validation failure.