Entity resolution for federation _entities query.
Structs
- Entity
Resolution Metrics - Result of batch entity resolution with timing information
- Entity
Resolution Result - Result of entity resolution
Functions
- batch_
load_ entities - Batch load entities from database
- batch_
load_ entities_ with_ tracing - Batch load entities from database with optional distributed tracing and metrics.
- batch_
load_ entities_ with_ tracing_ and_ metrics - Batch load entities with full metrics for observability.
- construct_
batch_ where_ clause - Construct WHERE clause for batch query
- deduplicate_
representations - Deduplicate entity representations while preserving order
- group_
entities_ by_ typename - Group entities by typename and strategy
- resolve_
entities_ from_ db - Resolve entities for a specific typename from local database
- resolve_
entities_ from_ db_ with_ tracing - Resolve entities for a specific typename from local database with optional distributed tracing.