Function value_to_string
Source pub fn value_to_string(value: &Value) -> Result<String>
Convert a JSON value to its string representation for use in SQL.
This is used for extracting key values before they are escaped and quoted.
Examples
ⓘvalue_to_string(&json!("test")) value_to_string(&json!(123))