Elo Rust target integration for compiled validators.
Provides infrastructure for compiling Elo expressions to Rust validators, caching compiled validators, and executing them with <1µs latency targets.
Elo is an expression language by Bernard Lambeau: https://elo-lang.org/
Structs
- EloRust
Validator - A single ELO Rust validator with generated code
- Rust
Validator Registry - Registry for managing ELO Rust validators
- Rust
Validator Registry Config - Configuration for the Rust validator registry