pub struct RuleMetadata {
pub rule: ValidationRule,
pub overrideable: bool,
pub inherited: bool,
pub source: String,
}Expand description
Metadata about a validation rule for inheritance tracking.
Fields
rule: ValidationRuleThe validation rule
overrideable: boolWhether this rule can be overridden by child types
inherited: boolWhether this rule is inherited from a parent type
source: StringThe source type name for tracking
Implementations
Sourceimpl RuleMetadata
impl RuleMetadata
Sourcepub fn new(rule: ValidationRule, source: impl Into<String>) -> Self
pub fn new(rule: ValidationRule, source: impl Into<String>) -> Self
Create a new rule metadata from a validation rule.
Sourcepub const fn non_overrideable(self) -> Self
pub const fn non_overrideable(self) -> Self
Mark this rule as non-overrideable.
Sourcepub const fn as_inherited(self) -> Self
pub const fn as_inherited(self) -> Self
Mark this rule as inherited.