pub enum InputObjectRule {
AnyOf {
fields: Vec<String>,
},
OneOf {
fields: Vec<String>,
},
ConditionalRequired {
if_field: String,
then_fields: Vec<String>,
},
RequiredIfAbsent {
absent_field: String,
then_fields: Vec<String>,
},
Custom {
name: String,
},
}Expand description
Rules that apply at the input object level.
Variants
AnyOf
At least one field from the set must be provided
OneOf
Exactly one field from the set must be provided
ConditionalRequired
If one field is present, others must be present
RequiredIfAbsent
If one field is absent, others must be present
Custom
Custom validator function name to invoke