pub fn validate_input_object(
input: &Value,
rules: &[InputObjectRule],
object_path: Option<&str>,
) -> Result<()>Expand description
Validate an input object against a set of rules.
Applies all rules to the input object and aggregates errors.
Arguments
input- The input object to validaterules- Rules to apply at the object levelobject_path- Optional path to the object for error reporting
Errors
Returns FraiseQLError::Validation if any input object rule fails.