Validation rule types and definitions.
This module defines the validation rules that can be applied to input fields in a GraphQL schema. Rules are serializable and can be embedded in the compiled schema.
Enums
- Validation
Rule - A validation rule that can be applied to a field.