Module rules

Module rules 

Validation rule types and definitions.

This module defines the validation rules that can be applied to input fields in a GraphQL schema. Rules are serializable and can be embedded in the compiled schema.

Structs

CompiledPattern
A regex pattern compiled once at construction or deserialisation time.

Enums

ValidationRule
A validation rule that can be applied to a field.