Validation rule types and definitions.
This module defines the validation rules that can be applied to input fields in a GraphQL schema. Rules are serializable and can be embedded in the compiled schema.
Structs
- Compiled
Pattern - A regex pattern compiled once at construction or deserialisation time.
Enums
- Validation
Rule - A validation rule that can be applied to a field.