pub struct LengthValidator { /* private fields */ }Expand description
String length validator.
Implementations
Sourceimpl LengthValidator
impl LengthValidator
Sourcepub const fn new(min: Option<usize>, max: Option<usize>) -> Self
pub const fn new(min: Option<usize>, max: Option<usize>) -> Self
Create a new length validator.
Sourcepub const fn validate_length(&self, value: &str) -> bool
pub const fn validate_length(&self, value: &str) -> bool
Validate that a string is within the specified length bounds.
Sourcepub fn error_message(&self) -> String
pub fn error_message(&self) -> String
Get a descriptive error message for length validation failure.