pub struct RangeValidator { /* private fields */ }Expand description
Numeric range validator.
Implementations
Sourceimpl RangeValidator
impl RangeValidator
Sourcepub const fn validate_range(&self, value: i64) -> bool
pub const fn validate_range(&self, value: i64) -> bool
Validate that a number is within the specified range.
Sourcepub fn error_message(&self) -> String
pub fn error_message(&self) -> String
Get a descriptive error message for range validation failure.